==> fluss-0.8.0-incubating-src.tgz: fluss-0.8.0-incubating/fluss-common/src/main/java/org/apache/fluss/row/arrow/writers/ArrowDateWriter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.fluss.row.arrow.writers;

import org.apache.fluss.annotation.Internal;
import org.apache.fluss.row.InternalRow;
import org.apache.fluss.shaded.arrow.org.apache.arrow.vector.DateDayVector;

/** {@link ArrowFieldWriter} for Date. */
@Internal
public class ArrowDateWriter extends ArrowFieldWriter<InternalRow> {

    public static ArrowDateWriter forField(DateDayVector dateDayVector) {
        return new ArrowDateWriter(dateDayVector);
    }

    private ArrowDateWriter(DateDayVector dateDayVector) {
        super(dateDayVector);
    }

    @Override
    public void doWrite(InternalRow row, int ordinal, boolean handleSafe) {
        DateDayVector vector = (DateDayVector) getValueVector();
        if (isNullAt(row, ordinal)) {
            vector.setNull(getCount());
        } else if (handleSafe) {
            vector.setSafe(getCount(), readDate(row, ordinal));
        } else {
            vector.set(getCount(), readDate(row, ordinal));
        }
    }

    private boolean isNullAt(InternalRow row, int ordinal) {
        return row.isNullAt(ordinal);
    }

    private int readDate(InternalRow row, int ordinal) {
        return row.getInt(ordinal);
    }
}

==> fluss-0.9.0-incubating-src.tgz: fluss-0.9.0-incubating/fluss-common/src/main/java/org/apache/fluss/row/arrow/writers/ArrowDateWriter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.fluss.row.arrow.writers;

import org.apache.fluss.annotation.Internal;
import org.apache.fluss.row.DataGetters;
import org.apache.fluss.shaded.arrow.org.apache.arrow.vector.DateDayVector;

/** {@link ArrowFieldWriter} for Date. */
@Internal
public class ArrowDateWriter extends ArrowFieldWriter {

    public ArrowDateWriter(DateDayVector dateDayVector) {
        super(dateDayVector);
    }

    @Override
    public void doWrite(int rowIndex, DataGetters row, int ordinal, boolean handleSafe) {
        DateDayVector vector = (DateDayVector) fieldVector;
        if (handleSafe) {
            vector.setSafe(rowIndex, readDate(row, ordinal));
        } else {
            vector.set(rowIndex, readDate(row, ordinal));
        }
    }

    private int readDate(DataGetters row, int ordinal) {
        return row.getInt(ordinal);
    }
}
